@@ -31,7 +31,8 @@ from .align_pipe import rotate_pixtables
 from .mpdaf_pipe import MuseCubeMosaic, MuseCube
 from .prep_recipes_pipe import dict_products_scipost
 from .version import __version__ as version_pack
-from .util_pipe import add_string, get_pointing_name, check_filter_list
+from .util_pipe import (add_string, get_pointing_name, get_dataset_name,
+                        check_filter_list)
 
 from astropy.table import Table
 
@@ -56,7 +57,9 @@ def insert_suffix(filename, suffix=""):
     """
     # Create new name
     sfilename, extension = os.path.splitext(filename)
-    return "{0}_{1}{2}".format(sfilename, suffix, extension)
+    if suffix != "":
+        suffix = f"_{suffix}"
+    return "{0}{1}{2}".format(sfilename, suffix, extension)
 
 
 def update_calib_file(filename, subfolder="", folder_config=""):
@@ -420,7 +423,7 @@ class MusePipeSample(object):
         if self.__phangs:
             config_args = PHANGS_reduc_config
             # Set overwrite to False to keep existing tables
-            config_args['overwrite_astropy_table'] = False
+            config_args['overwrite_astropy_tables'] = False
         else:
             config_args = kwargs.pop("config_args", None)
 
@@ -874,8 +877,9 @@ class MusePipeSample(object):
                              list_ifu=None, angle=angle, fakemode=fakemode,
                              prefix=prefix, **kwargs)
 
-    def init_mosaic(self, targetname=None, list_pointings=None,
-                    prefix_cubes="DATACUBE_FINAL_WCS", **kwargs):
+    def init_mosaic(self, targetname=None, list_datasets=None, 
+                    prefix_cubes="DATACUBE_FINAL_WCS", 
+                    list_pointings=None, **kwargs):
         """Prepare the combination of targets
 
         Input
@@ -886,14 +890,22 @@ class MusePipeSample(object):
             List of datasets (e.g., [1,2,3])
         """
         add_targetname = kwargs.pop("add_targetname", self.add_targetname)
-        # # Check if datasets are valid
-        # list_pointings = self._check_list_datasets_for_target(targetname, list_pointings)
-        if len(list_pointings) == 0:
-            return
+        # Check if pointings are ok
+        if list_pointings is not None:
+            if len(list_pointings) == 0:
+                return
+
+        if list_pointings is None:
+            list_pointings = copy.copy(self.targets[targetname].list_datasets)
+        if list_datasets is None:
+            list_datasets = copy.copy(self.targets[targetname].list_datasets)
 
         # Make a list for the masking of the cubes to take into account
         list_pointings_names = [f"{get_pointing_name(pointing)}"
                                 for pointing in list_pointings]
+        list_datasets_names = [f"{get_dataset_name(dataset)}"
+                                for dataset in list_datasets]
+        upipe.print_info(f"List of pointing names: {list_pointings_names}")
 
         default_comb_folder = self.targets[targetname].combcubes_path
         folder_ref_wcs = kwargs.pop("folder_ref_wcs", default_comb_folder)
@@ -905,12 +917,13 @@ class MusePipeSample(object):
             wcs_prefix = ""
         ref_wcs = kwargs.pop("ref_wcs", "{0}{1}DATACUBE_FINAL.fits".format(
                              default_prefix_wcs_mosaic, wcs_prefix))
+        upipe.print_info(f"Check file: ref_wcs is {ref_wcs}")
 
         self.pipes_mosaic[targetname] = MuseCubeMosaic(ref_wcs=ref_wcs,
                                                        folder_ref_wcs=folder_ref_wcs,
                                                        folder_cubes=folder_cubes,
                                                        prefix_cubes=prefix_cubes,
-                                                       list_suffix=list_pointings_names,
+                                                       list_suffix=list_datasets_names,
                                                        **kwargs)
 
     def convolve_mosaic_per_pointing(self, targetname=None, list_pointings=None,
