@@ -20,7 +20,6 @@ from astropy.io import fits as pyfits
 # Import package modules
 from .config_pipe import (default_filter_list, dict_musemodes, default_short_filter_list,
                           default_ndigits, default_str_pointing, default_str_dataset)
-from . import util_pipe as upipe
 
 
 #  PRINTING FUNCTIONS #
@@ -128,8 +127,8 @@ def filter_list_to_str(filter_list):
         return fl
     elif type(filter_list) is str:
         return filter_list
-    else
-        upipe.print_warning(f"Could not recognise type of filter_list {filter_list}")
+    else:
+        print_warning(f"Could not recognise type of filter_list {filter_list}")
         return ""
 
 
@@ -141,8 +140,8 @@ def check_filter_list(filter_list):
         return filter_list
     elif type(filter_list) is str:
         return filter_list.split(',')
-    else
-        upipe.print_warning(f"Could not recognise type of filter_list {filter_list}")
+    else:
+        print_warning(f"Could not recognise type of filter_list {filter_list}")
         return []
 
 
@@ -164,14 +163,14 @@ def analyse_musemode(musemode, field, delimiter='-'):
         Value of the field which was analysed (e.g., 'AO' or 'NOAO')
     """
     if field not in dict_musemodes:
-        upipe.print_error(f"Cannot find such a field ({field}) in the dict_musemodes")
+        print_error(f"Cannot find such a field ({field}) in the dict_musemodes")
         return ""
 
     index = dict_musemodes[field]
     sval = musemode.split(delimiter)
 
     if len(sval) < index+1:
-        upipe.print_error(f"Error in analyse_musemode. Cannot access field {index} "
+        print_error(f"Error in analyse_musemode. Cannot access field {index} "
                           f"After splitting the musemode {musemode} = sval")
         val = ""
     else:
@@ -479,12 +478,13 @@ def filter_list_with_pdict(input_list, list_datasets=None,
         exposure_list_per_pointing: selected list of files for each pointing
 
     """
-    nfiles_input_list = len(input_list)
     if list_datasets is None:
-        list_datasets = dict_files.keys()
-    elif not isinstance(list_datasets, list):
-        upipe.print_error("Cannot recognise input dataset(s)")
         list_datasets = []
+    elif not isinstance(list_datasets, list):
+        print_error("Cannot recognise input dataset(s)")
+        list_datasets = []
+
+    nfiles_input_list = len(input_list)
 
     # If not dictionary is provided, we try to build it
     if dict_files is None:
@@ -493,20 +493,45 @@ def filter_list_with_pdict(input_list, list_datasets=None,
         # Building the dummy list of tpl and nexpo for
         # this input list, decrypting with get_tpl_nexpo
         dict_files = {}
+        dict_files_with_tpl = {}
         for filename in input_list:
+            if verbose:
+                print_info(f"Adressing File name: {filename}")
             fdataset, ftpl, fnexpo = get_dataset_tpl_nexpo(filename, str_dataset=str_dataset,
                                                            ndigits=ndigits)
+            if verbose:
+                print_info(f"Adressing File name: {filename}")
+                print_info(f"    Detected = Dataset/TPLS/Nexpo: {fdataset} / {ftpl} / {fnexpo}")
             # Did not find the string associated with dataset
             if fdataset == -1:
                 continue
             # or found it, then record it
             else:
                 # Record only if the input list
-                if fdataset in list_datasets:
-                    if fdataset not in dict_files:
-                        dict_files[fdataset] = [[ftpl, fnexpo]]
+                if fdataset in list_datasets or len(list_datasets)==0:
+                    if fdataset not in dict_files_with_tpl:
+                        dict_files_with_tpl[fdataset] = {ftpl: [fnexpo]}
                     else:
-                        dict_files[fdataset].append([ftpl, fnexpo])
+                        if ftpl not in dict_files_with_tpl[fdataset]:
+                            dict_files_with_tpl[fdataset][ftpl] = [fnexpo]
+                        else:
+                            dict_files_with_tpl[fdataset][ftpl].append(fnexpo)
+
+                for dataset in dict_files_with_tpl:
+                    dict_files[dataset] = []
+                    for tpl in dict_files_with_tpl[dataset]:
+                        list_nexpo = []
+                        for nexpo in dict_files_with_tpl[dataset][tpl]:
+                            list_nexpo.append(nexpo)
+                        list_nexpo.sort()
+                        dict_files[dataset].append((tpl, list_nexpo))
+
+    if len(list_datasets) == 0:
+        list_datasets = list(dict_files.keys())
+
+    if verbose:
+        print_info(f"Check file = dict_files is : {dict_files}")
+        print_info(f"Check file = list_datasets is : {list_datasets}")
 
         # if len(dict_files) == 0:
         #     list_tplexpo = []
@@ -538,7 +563,7 @@ def filter_list_with_pdict(input_list, list_datasets=None,
     for dataset in list_datasets:
         dict_tplexpo_per_dataset[dataset] = {}
         if dataset not in dict_files:
-            upipe.print_warning("Dataset {} not in dictionary "
+            print_warning("Dataset {} not in dictionary "
                                 "- skipping".format(dataset))
         else:
             list_tpltuple = dict_files[dataset]
@@ -561,9 +586,9 @@ def filter_list_with_pdict(input_list, list_datasets=None,
                         nexpo = int(expo[0])
                         pointing = int(expo[1])
                     else:
-                        upipe.print_warning(f"Dictionary entry {expotuple} "
-                                            f"ignored (type of expo - {expo} - "
-                                            f"is {type(expo)}")
+                        print_warning(f"Dictionary entry {expotuple} "
+                                      f"ignored (type of expo - {expo} - "
+                                      f"is {type(expo)}")
                         break
 
                     # Check whether this exists in the our cube list
@@ -578,7 +603,7 @@ def filter_list_with_pdict(input_list, list_datasets=None,
                             dict_exposures_per_pointing[pointing].append(filename)
                             dict_tplexpo_per_pointing[pointing].append([dataset, tpl,
                                                                         nexpo])
-                            if pointing not in dict_tplexpo_per_dataset:
+                            if pointing not in dict_tplexpo_per_dataset[dataset]:
                                 dict_tplexpo_per_dataset[dataset][pointing] = []
                             dict_tplexpo_per_dataset[dataset][pointing].append([tpl, nexpo])
                             # And remove it from the list
@@ -587,15 +612,15 @@ def filter_list_with_pdict(input_list, list_datasets=None,
                             break
 
     if verbose:
-        upipe.print_info("Datasets {0} - Selected {1}/{2} exposures after "
-                         "dictionary filtering".format(list_datasets,
-                                                len(selected_filename_list),
-                                                nfiles_input_list))
+        print_info("Datasets {0} - Selected {1}/{2} exposures after "
+                   "dictionary filtering".format(list_datasets,
+                                          len(selected_filename_list),
+                                          nfiles_input_list))
 
         for pointing in dict_tplexpo_per_pointing:
-            upipe.print_info(f"Pointing {pointing} - Detected exposures [DATASET / TPL / NEXPO]:")
+            print_info(f"Pointing {pointing} - Detected exposures [DATASET / TPL / NEXPO]:")
             for tplexpo in dict_tplexpo_per_pointing[pointing]:
-                upipe.print_info(f"     {tplexpo[0]} / {tplexpo[1]} / {tplexpo[2]}")
+                print_info(f"     {tplexpo[0]} / {tplexpo[1]} / {tplexpo[2]}")
 
     return selected_filename_list, dict_exposures_per_pointing, dict_tplexpo_per_pointing, \
         dict_tplexpo_per_dataset
@@ -619,8 +644,8 @@ def filter_list_with_suffix_list(list_names, included_suffix_list=[],
 
     # if the list of inclusion suffix is empty, just use all cubes
     if len(included_suffix_list) > 0:
-        upipe.print_info(f"Using suffixes {included_suffix_list} "
-                         f"as an inclusive condition {add_message}")
+        print_info(f"Using suffixes {included_suffix_list} "
+                   f"as an inclusive condition {add_message}")
         # Filtering out the ones that don't have any of the suffixes
         temp_list = copy.copy(list_names)
         for l in temp_list:
@@ -629,8 +654,8 @@ def filter_list_with_suffix_list(list_names, included_suffix_list=[],
 
     # if the list of exclusion suffix is empty, just use all cubes
     if len(excluded_suffix_list) > 0:
-        upipe.print_info(f"Using suffixes {excluded_suffix_list} "
-                         f"as an exclusive condition {add_message}")
+        print_info(f"Using suffixes {excluded_suffix_list} "
+                   f"as an exclusive condition {add_message}")
         # Filtering out the ones that have any of the suffixes
         temp_list = copy.copy(list_names)
         for l in temp_list:
